@@ -11,5 +11,6 @@ from apypie.api import Api
 from apypie.example import Example
 from apypie.param import Param
 from apypie.inflector import Inflector
+from apypie.foreman import ForemanApi, ForemanApiException
 
-__all__ = ['Api', 'Resource', 'Route', 'Action', 'Example', 'Param', 'Inflector']
+__all__ = ['Api', 'Resource', 'Route', 'Action', 'Example', 'Param', 'Inflector', 'ForemanApi', 'ForemanApiException']
