@@ -1,15 +1,20 @@
+"""
+Apypie Example module
+"""
+
 import re
 
 
 EXAMPLE_PARSER = re.compile(r'(\w+)\s+([^\n]*)\n?(.*)\n(\d+)\n(.*)', re.DOTALL)
 
 
-class Example:
+class Example(object):  # pylint: disable=too-few-public-methods
     """
     Apipie Example
     """
 
-    def __init__(self, http_method, path, args, status, response):
+    def __init__(self, http_method, path, args, status, response):  # pylint: disable=too-many-arguments
+        # type: (str, str, str, str, str) -> None
         self.http_method = http_method
         self.path = path
         self.args = args
@@ -18,5 +23,10 @@ class Example:
 
     @classmethod
     def parse(cls, example):
+        """
+        Parse an example from an apidoc string
+
+        :returns: The parsed :class:`Example`
+        """
         parsed = EXAMPLE_PARSER.match(example)
         return cls(*parsed.groups())
