@@ -7,10 +7,7 @@ Inflection rules taken from davidcelis's Inflections (https://github.com/davidce
 
 import re
 
-try:
-    from typing import Iterable, Tuple  # pylint: disable=unused-import
-except ImportError:
-    pass
+from typing import Iterable, Tuple  # pylint: disable=unused-import  # noqa: F401
 
 
 class Inflections(object):
@@ -137,6 +134,7 @@ class Inflector(object):
         self.inflections.irregular('person', 'people')
         self.inflections.irregular('self', 'selves')
         self.inflections.irregular('sex', 'sexes')
+        self.inflections.irregular('erratum', 'errata')
 
         self.inflections.uncountable('equipment', 'information', 'money', 'species', 'series', 'fish', 'sheep', 'police')
 
