@@ -4,10 +4,9 @@ Apypie Route module
 
 from __future__ import print_function, absolute_import
 
-try:
-    from typing import List, Optional  # pylint: disable=unused-import
-except ImportError:
-    pass
+from urllib.parse import quote  # type: ignore
+
+from typing import List, Optional  # pylint: disable=unused-import  # noqa: F401
 
 
 class Route(object):
@@ -42,7 +41,7 @@ class Route(object):
         if params is not None:
             for param in self.params_in_path:
                 if param in params:
-                    result = result.replace(':{}'.format(param), str(params[param]))
+                    result = result.replace(':{}'.format(param), quote(str(params[param]), safe=''))
                 else:
                     raise KeyError("missing param '{}' in parameters".format(param))
         return result
